@@ -7,22 +7,29 @@
 #' one representative for each clump.
 #'
 #' @export
-#' @param clumpingResult clumpProcedure output
-#' @param fdr, numeric, False Discovery Rate for SLOPE
+#' @param clumpingResult object of class \code{\link{clumpingResult}}, 
+#' clumpProcedure output.
+#' @param fdr, numeric, False Discovery Rate for SLOPE.
 #' @param type method for snp selection. slope (default value) is SLOPE
-#' on clump representatives, smt is Benjamini-Hochberg procedure on
-#' single marker test p-values for clump representatives
-#' @param lambda lambda for SLOPE. See \code{\link[SLOPE]{create_lambda}}
-#' @param sigma numeric, sigma for SLOPE
-#' @param verbose logical, if TRUE progress bar is printed
-#' @return object of class \code{\link{selectionResult}}
+#' on clump representatives, smt is the Benjamini-Hochberg procedure on
+#' single marker test p-values for clump representatives.
+#' @param lambda lambda for SLOPE. See \code{\link{create_lambda}}.
+#' @param sigma numeric, sigma for SLOPE.
+#' @param verbose logical, if TRUE progress bar is printed.
+#' @return object of class \code{\link{selectionResult}}.
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
+#' famFile <- system.file("extdata", "plinkPhenotypeExample.fam", package = "geneSLOPE")
+#' mapFile <- system.file("extdata", "plinkMapExample.map", package = "geneSLOPE")
+#' snpsFile <- system.file("extdata", "plinkDataExample.raw", package = "geneSLOPE")
+#' phe <- read_phenotype(filename = famFile)
+#' screening.result <- screen_snps(snpsFile, mapFile, phe, pValMax = 0.05, chunkSize = 1e2)
+#' clumping.result <- clump_snps(screening.result, rho = 0.3, verbose = TRUE)
 #' slope.result <- select_snps(clumping.result, fdr=0.1)
 #' }
-select_snps <- function(clumpingResult, fdr = 0.1, type=c("slope", "smt"),
-                        lambda="gaussian", sigma=NULL, verbose = TRUE){
+select_snps <- function(clumpingResult, fdr = 0.1, type = c("slope", "smt"),
+                        lambda = "gaussian", sigma = NULL, verbose = TRUE){
   if(fdr>=1 | fdr <= 0){
     stop("FDR has to be within range (0,1)")
   }
@@ -31,8 +38,8 @@ select_snps <- function(clumpingResult, fdr = 0.1, type=c("slope", "smt"),
          number of rows in X")
   }
 
-  if(type=="slope"){
-    lambda <- SLOPE::create_lambda(length(clumpingResult$y),
+  if(any(type=="slope")){
+    lambda <- create_lambda(length(clumpingResult$y),
                                    clumpingResult$numberOfSnps, fdr, "gaussian")
     lambda <- lambda[1:ncol(clumpingResult$X)]
     lambda_diffs <- diff(lambda)
@@ -40,26 +47,28 @@ select_snps <- function(clumpingResult, fdr = 0.1, type=c("slope", "smt"),
       warning("All lambdas are equal. SLOPE does not guarantee
             False Discovery Rate control")
     }
-
+    # lambdas from the previous SLOPE implementation have to be divided by the sqrt(n)
+    # as LASSO scaling of the loss function is used
+    lambda <- lambda / sqrt(nrow(clumpingResult$X))
+    
     if (is.null(sigma) && (nrow(clumpingResult$X) >= ncol(clumpingResult$X) + 30)) {
       selected = NULL
       repeat {
         selected.prev = selected
         sigma = c(sigma, estimate_noise(clumpingResult$X[, selected], clumpingResult$y))
-        result = SLOPE::SLOPE(clumpingResult$X, clumpingResult$y, fdr = fdr,
-                              lambda = lambda, sigma = tail(sigma, 1))
-        selected = result$selected
+        result = SLOPE::SLOPE(x = clumpingResult$X, y = clumpingResult$y,
+                              q = fdr, lambda = lambda, alpha = tail(sigma, 1))
+        selected = which(result$nonzeros)
         if (identical(selected, selected.prev))
           break
       }
       sigma = tail(sigma, 1)
     }
 
-    slopeResult <- SLOPE::SLOPE(X = clumpingResult$X, y = clumpingResult$y,
-                                fdr = fdr, lambda = lambda, sigma = sigma)
-
-    selectedSNPs <- unlist(clumpingResult$SNPnumber)[slopeResult$selected]
-    selected = slopeResult$selected
+    slopeResult <- SLOPE::SLOPE(x = clumpingResult$X, y = clumpingResult$y,
+                                q = fdr, lambda = lambda, alpha = sigma)
+    selected = which(slopeResult$nonzeros)
+    selectedSNPs <- unlist(clumpingResult$SNPnumber)[selected]
     selectedSNPs <- sort(selectedSNPs)
   } else if(type=="smt"){
     repPVals = clumpingResult$pVals[clumpingResult$selectedSnpsNumbers]
@@ -71,7 +80,7 @@ select_snps <- function(clumpingResult, fdr = 0.1, type=c("slope", "smt"),
   }
 
 
-  X_selected <- clumpingResult$X_all[,selectedSNPs]
+  X_selected <- clumpingResult$X_all[,selectedSNPs, drop = FALSE]
   if(length(selectedSNPs)==0) {
     lm.fit.summary <- summary(lm(clumpingResult$y~1))
   } else {
